@@ -24,6 +24,8 @@
 #include <QCoreApplication>
 #include <QDebug>
 #include <QStringList>
+#include <QCryptographicHash>
+#include <QTextStream>
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDBusConnectionInterface>
@@ -39,6 +41,15 @@ LogViewerService::LogViewerService(QObject *parent)
     m_commands.insert("journalctl_boot", "journalctl -b -r");
 }
 
+LogViewerService::~LogViewerService()
+{
+    if(!m_logMap.isEmpty()) {
+        for(auto eachPair : m_logMap) {
+            delete eachPair.second;
+        }
+    }
+}
+
 /*!
  * \~chinese \brief LogViewerService::readLog 读取日志文件
  * \~chinese \param filePath 文件路径
@@ -53,9 +64,77 @@ QString LogViewerService::readLog(const QString &filePath)
     m_process.start("cat", QStringList() << filePath);
     m_process.waitForFinished(-1);
     QByteArray byte = m_process.readAllStandardOutput();
+
+    //QByteArray -> QString 如果遇到0x00，会导致转换终止
+    //replace("\x00", "")和replace("\u0000", "")无效
+    for(int i = 0;i != byte.size();++i) {
+        if(byte.at(i) == 0x00) {
+            byte.remove(i, 1);
+            i--;
+        }
+    }
+
     return QString::fromUtf8(byte);
 }
 
+/*!
+ * \~chinese \brief LogViewerService::openLogStream 打开一个日志文件的流式读取通道
+ * \~chinese \param filePath 文件路径
+ * \~chinese \return 通道token，返回空时表示文件路径无效
+ */
+QString LogViewerService::openLogStream(const QString &filePath)
+{
+    QString result = readLog(filePath);
+    if(result == " ") {
+        return "";
+    }
+
+    QString token = QCryptographicHash::hash(filePath.toUtf8(), QCryptographicHash::Md5).toHex();
+
+    auto stream = new QTextStream;
+
+    m_logMap[token] = std::make_pair(result, stream);
+    stream->setString(&(m_logMap[token].first), QIODevice::ReadOnly);
+
+    return token;
+}
+
+/*!
+ * \~chinese \brief LogViewerService::readLogInStream 从刚刚打开的传输通道中读取日志数据
+ * \~chinese \param token 通道token
+ * \~chinese \return 读取的日志，返回为空的时候表示读取结束或token无效
+ */
+QString LogViewerService::readLogInStream(const QString &token)
+{
+    if(!m_logMap.contains(token)) {
+        return "";
+    }
+
+    auto stream = m_logMap[token].second;
+
+    QString result;
+    constexpr int maxReadSize = 10 * 1024 * 1024;
+    while (1) {
+        auto data = stream->readLine();
+        if(data.isEmpty()) {
+            break;
+        }
+
+        result += data + '\n';
+
+        if(result.size() > maxReadSize) {
+            break;
+        }
+    }
+
+    if(result.isEmpty()) {
+        delete m_logMap[token].second;
+        m_logMap.remove(token);
+    }
+
+    return result;
+}
+
 /*!
  * \~chinese \brief LogViewerService::exitCode 返回进程状态
  * \~chinese \return 进程返回值
@@ -135,9 +214,17 @@ QStringList LogViewerService::getFileInfo(const QString &file, bool unzip)
 
 bool LogViewerService::exportLog(const QString &outDir, const QString &in, bool isFile)
 {
-    if (outDir.isEmpty() || in.isEmpty()) {
+    QFileInfo outDirInfo;
+    if(!outDir.endsWith("/")) {
+        outDirInfo.setFile(outDir + "/");
+    } else {
+        outDirInfo.setFile(outDir);
+    }
+
+    if (!outDirInfo.isDir() || in.isEmpty()) {
         return false;
     }
+
     QString outFullPath = "";
     QStringList arg = {"-c", ""};
     if (isFile) {
@@ -150,21 +237,21 @@ bool LogViewerService::exportLog(const QString &outDir, const QString &in, bool
             qInfo() << "in not file:" << in;
             return false;
         }
-        outFullPath = outDir + filein.fileName();
+        outFullPath = outDirInfo.absoluteFilePath() + filein.fileName();
         //复制文件
-        arg[1].append(QString("cp %1 %2;").arg(in, outDir));
+        arg[1].append(QString("cp %1 \"%2\";").arg(in, outDirInfo.absoluteFilePath()));
     } else {
         auto it = m_commands.find(in);
         if (it == m_commands.end()) {
             qInfo() << "unknown command:" << in;
             return false;
         }
-        outFullPath = outDir + in + ".txt";
+        outFullPath = outDirInfo.absoluteFilePath() + in + ".txt";
         //结果重定向到文件
-        arg[1].append(QString("%1 >& %2;").arg(it.value(), outFullPath));
+        arg[1].append(QString("%1 >& \"%2\";").arg(it.value(), outFullPath));
     }
     //设置文件权限
-    arg[1].append(QString("chmod 777 %1;").arg(outFullPath));
+    arg[1].append(QString("chmod 777 \"%1\";").arg(outFullPath));
     QProcess process;
     process.start("/bin/bash", arg);
     if (!process.waitForFinished()) {
